@@ -97,9 +97,13 @@ class API:
 
     def _solve_audio_challenge(self) -> None:
         try:
-            block_message = self.__driver.find_element(by='class name', value='rc-doscaptcha-header-text').text
+            block_message = self._wait_for_element(
+                tag='class name',
+                locator='rc-doscaptcha-header-text',
+                timeout=1,
+            )
 
-            if block_message == 'Try again later':
+            if getattr(block_message, 'text') == 'Try again later':
                 raise RecaptchaException('Google has detected automated queries. Try again later.')
 
         except TimeoutException:
